/* automatically generated from accessibility-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (accessibility_dialog_ui)
#endif
#ifdef __GNUC__
static const char accessibility_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char accessibility_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\"?><interface><requires lib=\"gtk+\" version=\"2.16"
  "\"/><object class=\"GtkAdjustment\" id=\"slow-keys-delay\"><property na"
  "me=\"value\">500</property><property name=\"lower\">50</property><prope"
  "rty name=\"upper\">1000</property><property name=\"step_increment\">10<"
  "/property><property name=\"page_increment\">100</property></object><obj"
  "ect class=\"GtkAdjustment\" id=\"bounce-keys-delay\"><property name=\"v"
  "alue\">500</property><property name=\"lower\">50</property><property na"
  "me=\"upper\">1000</property><property name=\"step_increment\">1</proper"
  "ty><property name=\"page_increment\">10</property></object><object clas"
  "s=\"GtkAdjustment\" id=\"mouse-emulation-delay\"><property name=\"value"
  "\">150</property><property name=\"lower\">1</property><property name=\""
  "upper\">1000</property><property name=\"step_increment\">10</property><"
  "property name=\"page_increment\">100</property></object><object class=\""
  "GtkAdjustment\" id=\"mouse-emulation-interval\"><property name=\"value\""
  ">20</property><property name=\"lower\">10</property><property name=\"up"
  "per\">1000</property><property name=\"step_increment\">1</property><pro"
  "perty name=\"page_increment\">10</property></object><object class=\"Gtk"
  "Adjustment\" id=\"mouse-emulation-curve\"><property name=\"lower\">-100"
  "0</property><property name=\"upper\">1000</property><property name=\"st"
  "ep_increment\">10</property><property name=\"page_increment\">100</prop"
  "erty></object><object class=\"GtkAdjustment\" id=\"mouse-emulation-max-"
  "speed\"><property name=\"value\">1000</property><property name=\"lower\""
  ">1</property><property name=\"upper\">2000</property><property name=\"s"
  "tep_increment\">10</property><property name=\"page_increment\">100</pro"
  "perty></object><object class=\"GtkAdjustment\" id=\"mouse-emulation-tim"
  "e-to-max\"><property name=\"value\">3000</property><property name=\"low"
  "er\">100</property><property name=\"upper\">10000</property><property n"
  "ame=\"step_increment\">10</property><property name=\"page_increment\">1"
  "00</property></object><object class=\"XfceTitledDialog\" id=\"dialog\">"
  "<property name=\"title\" translatable=\"yes\">Accessibility</property><"
  "property name=\"window_position\">center-on-parent</property><property "
  "name=\"icon_name\">preferences-desktop-accessibility</property><propert"
  "y name=\"type_hint\">dialog</property><property name=\"subtitle\" trans"
  "latable=\"yes\">Configure keyboard and mouse accessibility</property><c"
  "hild internal-child=\"vbox\"><object class=\"GtkVBox\" id=\"dialog-vbox"
  "1\"><property name=\"visible\">True</property><property name=\"orientat"
  "ion\">vertical</property><property name=\"spacing\">2</property><child>"
  "<object class=\"GtkVBox\" id=\"plug-child\"><property name=\"visible\">"
  "True</property><child><object class=\"GtkNotebook\" id=\"notebook1\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Tr"
  "ue</property><property name=\"border_width\">6</property><child><object"
  " class=\"GtkVBox\" id=\"vbox1\"><property name=\"visible\">True</proper"
  "ty><property name=\"border_width\">6</property><property name=\"orienta"
  "tion\">vertical</property><property name=\"spacing\">6</property><child"
  "><object class=\"GtkCheckButton\" id=\"start-at\"><property name=\"labe"
  "l\" translatable=\"yes\">_Enable assistive technologies</property><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">True<"
  "/property><property name=\"receives_default\">False</property><property"
  " name=\"tooltip_text\" translatable=\"yes\">If enabled, the session man"
  "ager will start the required applications for screen readers and magnif"
  "iers</property><property name=\"use_underline\">True</property><propert"
  "y name=\"draw_indicator\">True</property></object><packing><property na"
  "me=\"expand\">False</property><property name=\"position\">0</property><"
  "/packing></child><child><object class=\"GtkAlignment\" id=\"alignment5\""
  "><property name=\"visible\">True</property><child><placeholder/></child"
  "></object><packing><property name=\"position\">1</property></packing></"
  "child><child><object class=\"GtkHBox\" id=\"info-logout\"><property nam"
  "e=\"spacing\">12</property><child><object class=\"GtkImage\" id=\"image"
  "1\"><property name=\"visible\">True</property><property name=\"stock\">"
  "gtk-info</property><property name=\"icon-size\">5</property></object><p"
  "acking><property name=\"expand\">False</property><property name=\"posit"
  "ion\">0</property></packing></child><child><object class=\"GtkLabel\" i"
  "d=\"label18\"><property name=\"visible\">True</property><property name="
  "\"xalign\">0</property><property name=\"label\" translatable=\"yes\">As"
  "sistive technologies will be available the\nnext time you login</proper"
  "ty><property name=\"wrap\">True</property></object><packing><property n"
  "ame=\"position\">1</property></packing></child></object><packing><prope"
  "rty name=\"expand\">False</property><property name=\"position\">2</prop"
  "erty></packing></child><child><object class=\"GtkHBox\" id=\"info-no-at"
  "\"><property name=\"spacing\">12</property><child><object class=\"GtkIm"
  "age\" id=\"image2\"><property name=\"visible\">True</property><property"
  " name=\"stock\">gtk-dialog-warning</property><property name=\"icon-size"
  "\">5</property></object><packing><property name=\"expand\">False</prope"
  "rty><property name=\"position\">0</property></packing></child><child><o"
  "bject class=\"GtkLabel\" id=\"label20\"><property name=\"visible\">True"
  "</property><property name=\"xalign\">0</property><property name=\"label"
  "\" translatable=\"yes\">No AT-SPI provider was found on your system</pr"
  "operty></object><packing><property name=\"position\">1</property></pack"
  "ing></child></object><packing><property name=\"expand\">False</property"
  "><property name=\"position\">3</property></packing></child></object></c"
  "hild><child type=\"tab\"><object class=\"GtkLabel\" id=\"label17\"><pro"
  "perty name=\"visible\">True</property><property name=\"label\" translat"
  "able=\"yes\">_Assistive Technologies</property><property name=\"use_und"
  "erline\">True</property></object><packing><property name=\"position\">2"
  "</property><property name=\"tab_fill\">False</property></packing></chil"
  "d><child><object class=\"GtkVBox\" id=\"vbox2\"><property name=\"visibl"
  "e\">True</property><property name=\"border_width\">12</property><proper"
  "ty name=\"orientation\">vertical</property><property name=\"spacing\">6"
  "</property><child><object class=\"GtkFrame\" id=\"frame1\"><property na"
  "me=\"visible\">True</property><property name=\"label_xalign\">0</proper"
  "ty><property name=\"shadow_type\">none</property><child><object class=\""
  "GtkAlignment\" id=\"alignment1\"><property name=\"visible\">True</prope"
  "rty><property name=\"bottom_padding\">6</property><property name=\"left"
  "_padding\">12</property><child><object class=\"GtkVBox\" id=\"vbox3\"><"
  "property name=\"visible\">True</property><property name=\"border_width\""
  ">6</property><property name=\"orientation\">vertical</property><propert"
  "y name=\"spacing\">6</property><child><object class=\"GtkCheckButton\" "
  "id=\"sticky-keys-enabled\"><property name=\"label\" translatable=\"yes\""
  ">Use _sticky keys</property><property name=\"visible\">True</property><"
  "property name=\"can_focus\">True</property><property name=\"receives_de"
  "fault\">False</property><property name=\"tooltip_text\" translatable=\""
  "yes\">When selected, modifier keys (such as Control, Alt, and Shift) do"
  " not need to be held down (they can be pressed and then released) when "
  "multiple keys would normally need to be pressed at the same time</prope"
  "rty><property name=\"use_underline\">True</property><property name=\"dr"
  "aw_indicator\">True</property></object><packing><property name=\"expand"
  "\">False</property><property name=\"fill\">False</property><property na"
  "me=\"position\">0</property></packing></child><child><object class=\"Gt"
  "kAlignment\" id=\"sticky-keys-box\"><property name=\"visible\">True</pr"
  "operty><property name=\"sensitive\">False</property><property name=\"le"
  "ft_padding\">18</property><child><object class=\"GtkVBox\" id=\"vbox7\""
  "><property name=\"visible\">True</property><property name=\"orientation"
  "\">vertical</property><property name=\"spacing\">6</property><child><ob"
  "ject class=\"GtkCheckButton\" id=\"sticky-keys-latch-to-lock\"><propert"
  "y name=\"label\" translatable=\"yes\">_Lock sticky keys</property><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">True<"
  "/property><property name=\"receives_default\">False</property><property"
  " name=\"tooltip_text\" translatable=\"yes\">When selected, modifier key"
  "s (such as Control, Alt, and Shift) will remain locked in the pressed s"
  "tate until pressed again</property><property name=\"use_underline\">Tru"
  "e</property><property name=\"draw_indicator\">True</property></object><"
  "packing><property name=\"position\">0</property></packing></child><chil"
  "d><object class=\"GtkCheckButton\" id=\"sticky-keys-two-keys-disable\">"
  "<property name=\"label\" translatable=\"yes\">Disable sticky keys if _t"
  "wo keys are pressed</property><property name=\"visible\">True</property"
  "><property name=\"can_focus\">True</property><property name=\"receives_"
  "default\">False</property><property name=\"tooltip_text\" translatable="
  "\"yes\">When selected, the \"sticky keys\" feature will be disabled if "
  "two keys are pressed simultaneously</property><property name=\"use_unde"
  "rline\">True</property><property name=\"xalign\">0</property><property "
  "name=\"yalign\">0</property><property name=\"draw_indicator\">True</pro"
  "perty></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">False</property><property name=\"position\">1</prope"
  "rty></packing></child></object></child></object><packing><property name"
  "=\"position\">1</property></packing></child></object></child></object><"
  "/child><child type=\"label\"><object class=\"GtkLabel\" id=\"label3\"><"
  "property name=\"visible\">True</property><property name=\"label\" trans"
  "latable=\"yes\">Sticky Keys</property><attributes><attribute name=\"wei"
  "ght\" value=\"bold\"/></attributes></object></child></object><packing><"
  "property name=\"expand\">False</property><property name=\"fill\">False<"
  "/property><property name=\"position\">0</property></packing></child><ch"
  "ild><object class=\"GtkFrame\" id=\"frame2\"><property name=\"visible\""
  ">True</property><property name=\"label_xalign\">0</property><property n"
  "ame=\"shadow_type\">none</property><child><object class=\"GtkAlignment\""
  " id=\"alignment2\"><property name=\"visible\">True</property><property "
  "name=\"bottom_padding\">6</property><property name=\"left_padding\">12<"
  "/property><child><object class=\"GtkVBox\" id=\"vbox4\"><property name="
  "\"visible\">True</property><property name=\"border_width\">6</property>"
  "<property name=\"orientation\">vertical</property><property name=\"spac"
  "ing\">6</property><child><object class=\"GtkCheckButton\" id=\"slow-key"
  "s-enabled\"><property name=\"label\" translatable=\"yes\">Use slow _key"
  "s</property><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"receives_default\">False</p"
  "roperty><property name=\"tooltip_text\" translatable=\"yes\">To help pr"
  "event accidental keystrokes, slow keys requires that a key is held for "
  "a certain minimum amount of time before the keystroke will be accepted<"
  "/property><property name=\"use_underline\">True</property><property nam"
  "e=\"draw_indicator\">True</property></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">False</property><prope"
  "rty name=\"position\">0</property></packing></child><child><object clas"
  "s=\"GtkAlignment\" id=\"slow-keys-box\"><property name=\"visible\">True"
  "</property><property name=\"sensitive\">False</property><property name="
  "\"left_padding\">18</property><child><object class=\"GtkHBox\" id=\"hbo"
  "x1\"><property name=\"visible\">True</property><property name=\"spacing"
  "\">12</property><child><object class=\"GtkLabel\" id=\"label6\"><proper"
  "ty name=\"visible\">True</property><property name=\"xalign\">0</propert"
  "y><property name=\"label\" translatable=\"yes\">Acceptance _delay:</pro"
  "perty><property name=\"use_underline\">True</property><property name=\""
  "mnemonic_widget\">slow-keys-scale</property></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">False</propert"
  "y><property name=\"position\">0</property></packing></child><child><obj"
  "ect class=\"GtkHScale\" id=\"slow-keys-scale\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">True</property><property"
  " name=\"tooltip_text\" translatable=\"yes\">The amount of time, in mill"
  "iseconds, that must elapse before a keystroke will be accepted</propert"
  "y><property name=\"adjustment\">slow-keys-delay</property><property nam"
  "e=\"digits\">0</property><property name=\"value_pos\">right</property><"
  "/object><packing><property name=\"position\">1</property></packing></ch"
  "ild></object></child></object><packing><property name=\"position\">1</p"
  "roperty></packing></child></object></child></object></child><child type"
  "=\"label\"><object class=\"GtkLabel\" id=\"label4\"><property name=\"vi"
  "sible\">True</property><property name=\"label\" translatable=\"yes\">Sl"
  "ow Keys</property><attributes><attribute name=\"weight\" value=\"bold\""
  "/></attributes></object></child></object><packing><property name=\"expa"
  "nd\">False</property><property name=\"fill\">False</property><property "
  "name=\"position\">1</property></packing></child><child><object class=\""
  "GtkFrame\" id=\"frame3\"><property name=\"visible\">True</property><pro"
  "perty name=\"label_xalign\">0</property><property name=\"shadow_type\">"
  "none</property><child><object class=\"GtkAlignment\" id=\"alignment3\">"
  "<property name=\"visible\">True</property><property name=\"left_padding"
  "\">12</property><child><object class=\"GtkVBox\" id=\"vbox6\"><property"
  " name=\"visible\">True</property><property name=\"border_width\">6</pro"
  "perty><property name=\"orientation\">vertical</property><property name="
  "\"spacing\">6</property><child><object class=\"GtkCheckButton\" id=\"bo"
  "unce-keys-enabled\"><property name=\"label\" translatable=\"yes\">Use _"
  "bounce keys</property><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">True</property><property name=\"receives_default\""
  ">False</property><property name=\"tooltip_text\" translatable=\"yes\">T"
  "o help prevent accidental multiple keystrokes, bounce keys imposes a mi"
  "nimum delay between keystrokes</property><property name=\"use_underline"
  "\">True</property><property name=\"draw_indicator\">True</property></ob"
  "ject><packing><property name=\"expand\">False</property><property name="
  "\"fill\">False</property><property name=\"position\">0</property></pack"
  "ing></child><child><object class=\"GtkAlignment\" id=\"bounce-keys-box\""
  "><property name=\"visible\">True</property><property name=\"sensitive\""
  ">False</property><property name=\"left_padding\">18</property><child><o"
  "bject class=\"GtkHBox\" id=\"hbox2\"><property name=\"visible\">True</p"
  "roperty><property name=\"spacing\">12</property><child><object class=\""
  "GtkLabel\" id=\"label9\"><property name=\"visible\">True</property><pro"
  "perty name=\"xalign\">0</property><property name=\"label\" translatable"
  "=\"yes\">K_eystroke delay:</property><property name=\"use_underline\">T"
  "rue</property><property name=\"mnemonic_widget\">bounce-keys-scale</pro"
  "perty></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">False</property><property name=\"position\">0</prope"
  "rty></packing></child><child><object class=\"GtkHScale\" id=\"bounce-ke"
  "ys-scale\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">True</property><property name=\"tooltip_text\" translatable="
  "\"yes\">The amount of time, in milliseconds, required between keystroke"
  "s</property><property name=\"adjustment\">bounce-keys-delay</property><"
  "property name=\"digits\">0</property><property name=\"value_pos\">right"
  "</property></object><packing><property name=\"position\">1</property></"
  "packing></child></object></child></object><packing><property name=\"pos"
  "ition\">1</property></packing></child></object></child></object></child"
  "><child type=\"label\"><object class=\"GtkLabel\" id=\"label5\"><proper"
  "ty name=\"visible\">True</property><property name=\"label\" translatabl"
  "e=\"yes\">Bounce Keys</property><attributes><attribute name=\"weight\" "
  "value=\"bold\"/></attributes></object></child></object><packing><proper"
  "ty name=\"expand\">False</property><property name=\"position\">2</prope"
  "rty></packing></child></object><packing><property name=\"position\">1</"
  "property></packing></child><child type=\"tab\"><object class=\"GtkLabel"
  "\" id=\"label1\"><property name=\"visible\">True</property><property na"
  "me=\"label\" translatable=\"yes\">Keyboa_rd</property><property name=\""
  "use_underline\">True</property></object><packing><property name=\"posit"
  "ion\">1</property><property name=\"tab_fill\">False</property></packing"
  "></child><child><object class=\"GtkVBox\" id=\"vbox5\"><property name=\""
  "visible\">True</property><property name=\"border_width\">12</property><"
  "property name=\"orientation\">vertical</property><child><object class=\""
  "GtkFrame\" id=\"frame4\"><property name=\"visible\">True</property><pro"
  "perty name=\"label_xalign\">0</property><property name=\"shadow_type\">"
  "none</property><child><object class=\"GtkAlignment\" id=\"alignment4\">"
  "<property name=\"visible\">True</property><property name=\"border_width"
  "\">6</property><property name=\"left_padding\">12</property><child><obj"
  "ect class=\"GtkVBox\" id=\"vbox8\"><property name=\"visible\">True</pro"
  "perty><property name=\"orientation\">vertical</property><property name="
  "\"spacing\">6</property><child><object class=\"GtkCheckButton\" id=\"mo"
  "use-emulation-enabled\"><property name=\"label\" translatable=\"yes\">_"
  "Use mouse emulation</property><property name=\"visible\">True</property"
  "><property name=\"can_focus\">True</property><property name=\"receives_"
  "default\">False</property><property name=\"tooltip_text\" translatable="
  "\"yes\">When selected, the mouse pointer can be controlled using the ke"
  "yboard number pad</property><property name=\"use_underline\">True</prop"
  "erty><property name=\"draw_indicator\">True</property></object><packing"
  "><property name=\"expand\">False</property><property name=\"fill\">Fals"
  "e</property><property name=\"position\">0</property></packing></child><"
  "child><object class=\"GtkAlignment\" id=\"mouse-emulation-box\"><proper"
  "ty name=\"visible\">True</property><property name=\"sensitive\">False</"
  "property><property name=\"left_padding\">18</property><child><object cl"
  "ass=\"GtkTable\" id=\"table1\"><property name=\"visible\">True</propert"
  "y><property name=\"n_rows\">5</property><property name=\"n_columns\">3<"
  "/property><property name=\"column_spacing\">12</property><property name"
  "=\"row_spacing\">6</property><child><object class=\"GtkLabel\" id=\"lab"
  "el16\"><property name=\"visible\">True</property><property name=\"xalig"
  "n\">0</property><property name=\"label\" translatable=\"yes\">R_epeat i"
  "nterval:</property><property name=\"use_underline\">True</property><pro"
  "perty name=\"mnemonic_widget\">interval-widget</property></object><pack"
  "ing><property name=\"top_attach\">1</property><property name=\"bottom_a"
  "ttach\">2</property><property name=\"x_options\">GTK_FILL</property></p"
  "acking></child><child><object class=\"GtkLabel\" id=\"label7\"><propert"
  "y name=\"visible\">True</property><property name=\"xalign\">0</property"
  "><property name=\"label\" translatable=\"yes\">_Acceleration delay:</pr"
  "operty><property name=\"use_underline\">True</property><property name=\""
  "mnemonic_widget\">delay-widget</property></object><packing><property na"
  "me=\"x_options\">GTK_FILL</property></packing></child><child><object cl"
  "ass=\"GtkLabel\" id=\"label19\"><property name=\"visible\">True</proper"
  "ty><property name=\"xalign\">0</property><property name=\"label\" trans"
  "latable=\"yes\">Acceleration _time:</property><property name=\"use_unde"
  "rline\">True</property><property name=\"mnemonic_widget\">ttm-widget</p"
  "roperty></object><packing><property name=\"top_attach\">2</property><pr"
  "operty name=\"bottom_attach\">3</property><property name=\"x_options\">"
  "GTK_FILL</property></packing></child><child><object class=\"GtkLabel\" "
  "id=\"label22\"><property name=\"visible\">True</property><property name"
  "=\"xalign\">0</property><property name=\"label\" translatable=\"yes\">M"
  "aximum _speed:</property><property name=\"use_underline\">True</propert"
  "y><property name=\"mnemonic_widget\">max-speed-widget</property></objec"
  "t><packing><property name=\"top_attach\">3</property><property name=\"b"
  "ottom_attach\">4</property><property name=\"x_options\">GTK_FILL</prope"
  "rty></packing></child><child><object class=\"GtkLabel\" id=\"label8\"><"
  "property name=\"visible\">True</property><property name=\"xalign\">0</p"
  "roperty><property name=\"label\" translatable=\"yes\">Acceleration _pro"
  "file:</property><property name=\"use_underline\">True</property><proper"
  "ty name=\"mnemonic_widget\">curve-widget</property></object><packing><p"
  "roperty name=\"top_attach\">4</property><property name=\"bottom_attach\""
  ">5</property><property name=\"x_options\">GTK_FILL</property></packing>"
  "</child><child><object class=\"GtkLabel\" id=\"label10\"><property name"
  "=\"visible\">True</property><property name=\"xalign\">0</property><prop"
  "erty name=\"label\" translatable=\"yes\">msec</property></object><packi"
  "ng><property name=\"left_attach\">2</property><property name=\"right_at"
  "tach\">3</property></packing></child><child><object class=\"GtkLabel\" "
  "id=\"label11\"><property name=\"visible\">True</property><property name"
  "=\"xalign\">0</property><property name=\"label\" translatable=\"yes\">m"
  "sec</property></object><packing><property name=\"left_attach\">2</prope"
  "rty><property name=\"right_attach\">3</property><property name=\"top_at"
  "tach\">1</property><property name=\"bottom_attach\">2</property></packi"
  "ng></child><child><object class=\"GtkLabel\" id=\"label13\"><property n"
  "ame=\"visible\">True</property><property name=\"xalign\">0</property><p"
  "roperty name=\"label\" translatable=\"yes\">msec</property></object><pa"
  "cking><property name=\"left_attach\">2</property><property name=\"right"
  "_attach\">3</property><property name=\"top_attach\">2</property><proper"
  "ty name=\"bottom_attach\">3</property></packing></child><child><object "
  "class=\"GtkLabel\" id=\"label14\"><property name=\"visible\">True</prop"
  "erty><property name=\"xalign\">0</property></object><packing><property "
  "name=\"left_attach\">2</property><property name=\"right_attach\">3</pro"
  "perty><property name=\"top_attach\">4</property><property name=\"bottom"
  "_attach\">5</property></packing></child><child><object class=\"GtkLabel"
  "\" id=\"label15\"><property name=\"visible\">True</property><property n"
  "ame=\"xalign\">0</property><property name=\"label\" translatable=\"yes\""
  ">pixels/sec</property></object><packing><property name=\"left_attach\">"
  "2</property><property name=\"right_attach\">3</property><property name="
  "\"top_attach\">3</property><property name=\"bottom_attach\">4</property"
  "></packing></child><child><object class=\"GtkSpinButton\" id=\"delay-wi"
  "dget\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">True</property><property name=\"tooltip_text\" translatable=\"ye"
  "s\">The time, in milliseconds, between the initial key press and first "
  "repeated motion event</property><property name=\"adjustment\">mouse-emu"
  "lation-delay</property><property name=\"numeric\">True</property><prope"
  "rty name=\"update_policy\">if-valid</property></object><packing><proper"
  "ty name=\"left_attach\">1</property><property name=\"right_attach\">2</"
  "property><property name=\"x_options\">GTK_FILL</property></packing></ch"
  "ild><child><object class=\"GtkSpinButton\" id=\"interval-widget\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">True<"
  "/property><property name=\"tooltip_text\" translatable=\"yes\">The time"
  ", in milliseconds, between repeated motion events</property><property n"
  "ame=\"adjustment\">mouse-emulation-interval</property><property name=\""
  "numeric\">True</property><property name=\"update_policy\">if-valid</pro"
  "perty></object><packing><property name=\"left_attach\">1</property><pro"
  "perty name=\"right_attach\">2</property><property name=\"top_attach\">1"
  "</property><property name=\"bottom_attach\">2</property><property name="
  "\"x_options\">GTK_FILL</property></packing></child><child><object class"
  "=\"GtkSpinButton\" id=\"curve-widget\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">True</property><property name=\""
  "tooltip_text\" translatable=\"yes\">The ramp used to reach maximum poin"
  "ter speed</property><property name=\"adjustment\">mouse-emulation-curve"
  "</property><property name=\"numeric\">True</property><property name=\"u"
  "pdate_policy\">if-valid</property></object><packing><property name=\"le"
  "ft_attach\">1</property><property name=\"right_attach\">2</property><pr"
  "operty name=\"top_attach\">4</property><property name=\"bottom_attach\""
  ">5</property><property name=\"x_options\">GTK_FILL</property></packing>"
  "</child><child><object class=\"GtkSpinButton\" id=\"max-speed-widget\">"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "True</property><property name=\"tooltip_text\" translatable=\"yes\">The"
  " maximum pointer speed after acceleration</property><property name=\"ad"
  "justment\">mouse-emulation-max-speed</property><property name=\"numeric"
  "\">True</property><property name=\"update_policy\">if-valid</property><"
  "/object><packing><property name=\"left_attach\">1</property><property n"
  "ame=\"right_attach\">2</property><property name=\"top_attach\">3</prope"
  "rty><property name=\"bottom_attach\">4</property><property name=\"x_opt"
  "ions\">GTK_FILL</property></packing></child><child><object class=\"GtkS"
  "pinButton\" id=\"ttm-widget\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">True</property><property name=\"tooltip_t"
  "ext\" translatable=\"yes\">The time, in milliseconds, to get to maximum"
  " speed</property><property name=\"adjustment\">mouse-emulation-time-to-"
  "max</property><property name=\"numeric\">True</property><property name="
  "\"update_policy\">if-valid</property></object><packing><property name=\""
  "left_attach\">1</property><property name=\"right_attach\">2</property><"
  "property name=\"top_attach\">2</property><property name=\"bottom_attach"
  "\">3</property><property name=\"x_options\">GTK_FILL</property></packin"
  "g></child></object></child></object><packing><property name=\"position\""
  ">1</property></packing></child></object></child></object></child><child"
  " type=\"label\"><object class=\"GtkLabel\" id=\"label12\"><property nam"
  "e=\"visible\">True</property><property name=\"label\" translatable=\"ye"
  "s\">Mouse Emulation</property><attributes><attribute name=\"weight\" va"
  "lue=\"bold\"/></attributes></object></child></object><packing><property"
  " name=\"expand\">False</property><property name=\"position\">0</propert"
  "y></packing></child></object><packing><property name=\"position\">2</pr"
  "operty></packing></child><child type=\"tab\"><object class=\"GtkLabel\""
  " id=\"label2\"><property name=\"visible\">True</property><property name"
  "=\"label\" translatable=\"yes\">_Mouse</property><property name=\"use_u"
  "nderline\">True</property></object><packing><property name=\"position\""
  ">2</property><property name=\"tab_fill\">False</property></packing></ch"
  "ild></object><packing><property name=\"position\">1</property></packing"
  "></child></object><packing><property name=\"position\">1</property></pa"
  "cking></child><child internal-child=\"action_area\"><object class=\"Gtk"
  "HButtonBox\" id=\"dialog-action_area1\"><property name=\"visible\">True"
  "</property><property name=\"layout_style\">end</property><child><object"
  " class=\"GtkButton\" id=\"button2\"><property name=\"label\">gtk-close<"
  "/property><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">True</property><property name=\"receives_default\">True</prop"
  "erty><property name=\"use_stock\">True</property></object><packing><pro"
  "perty name=\"expand\">False</property><property name=\"fill\">False</pr"
  "operty><property name=\"position\">0</property></packing></child><child"
  "><object class=\"GtkButton\" id=\"button1\"><property name=\"label\">gt"
  "k-help</property><property name=\"use_action_appearance\">False</proper"
  "ty><property name=\"visible\">True</property><property name=\"can_focus"
  "\">True</property><property name=\"receives_default\">True</property><p"
  "roperty name=\"use_stock\">True</property></object><packing><property n"
  "ame=\"expand\">False</property><property name=\"fill\">False</property>"
  "<property name=\"position\">0</property><property name=\"secondary\">Tr"
  "ue</property></packing></child></object><packing><property name=\"expan"
  "d\">False</property><property name=\"pack_type\">end</property><propert"
  "y name=\"position\">0</property></packing></child></object></child><act"
  "ion-widgets><action-widget response=\"0\">button2</action-widget><actio"
  "n-widget response=\"-11\">button1</action-widget></action-widgets></obj"
  "ect></interface>"
};

static const unsigned accessibility_dialog_ui_length = 27270u;

