/* automatically generated from appearance-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (appearance_dialog_ui)
#endif
#ifdef __GNUC__
static const char appearance_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char appearance_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\"?><interface><object class=\"GtkAdjustment\" id=\""
  "xft_custom_dpi\"><property name=\"lower\">48</property><property name=\""
  "upper\">1000</property><property name=\"value\">96</property><property "
  "name=\"step_increment\">1</property><property name=\"page_increment\">1"
  "0</property></object><object class=\"GtkListStore\" id=\"liststore1\"><"
  "columns><column type=\"gchararray\"/></columns><data><row><col id=\"0\""
  " translatable=\"yes\">None</col></row><row><col id=\"0\" translatable=\""
  "yes\">Slight</col></row><row><col id=\"0\" translatable=\"yes\">Medium<"
  "/col></row><row><col id=\"0\" translatable=\"yes\">Full</col></row></da"
  "ta></object><object class=\"GtkListStore\" id=\"liststore2\"><columns><"
  "column type=\"gchararray\"/></columns><data><row><col id=\"0\" translat"
  "able=\"yes\">Icons</col></row><row><col id=\"0\" translatable=\"yes\">T"
  "ext</col></row><row><col id=\"0\" translatable=\"yes\">Both</col></row>"
  "<row><col id=\"0\" translatable=\"yes\">Both Horizontal</col></row></da"
  "ta></object><object class=\"GtkListStore\" id=\"xft_rgba_store\"><colum"
  "ns><column type=\"GdkPixbuf\"/><column type=\"gchararray\"/></columns><"
  "/object><object class=\"XfceTitledDialog\" id=\"dialog\"><property name"
  "=\"title\" translatable=\"yes\">Appearance</property><property name=\"w"
  "indow_position\">center-on-parent</property><property name=\"icon_name\""
  ">preferences-desktop-theme</property><property name=\"type_hint\">dialo"
  "g</property><property name=\"has_separator\">False</property><property "
  "name=\"subtitle\" translatable=\"yes\">Customize the look of your deskt"
  "op</property><child internal-child=\"vbox\"><object class=\"GtkVBox\" i"
  "d=\"dialog-vbox1\"><property name=\"visible\">True</property><property "
  "name=\"orientation\">vertical</property><property name=\"spacing\">2</p"
  "roperty><child><object class=\"GtkNotebook\" id=\"plug-child\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">True</pr"
  "operty><property name=\"border_width\">6</property><child><object class"
  "=\"GtkScrolledWindow\" id=\"scrolledwindow2\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property><property n"
  "ame=\"border_width\">12</property><property name=\"hscrollbar_policy\">"
  "automatic</property><property name=\"vscrollbar_policy\">automatic</pro"
  "perty><property name=\"shadow_type\">etched-in</property><child><object"
  " class=\"GtkTreeView\" id=\"gtk_theme_treeview\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">True</property><proper"
  "ty name=\"headers_visible\">False</property><property name=\"show_expan"
  "ders\">False</property></object></child></object></child><child type=\""
  "tab\"><object class=\"GtkLabel\" id=\"label1\"><property name=\"visible"
  "\">True</property><property name=\"label\" translatable=\"yes\">St_yle<"
  "/property><property name=\"use_underline\">True</property></object><pac"
  "king><property name=\"tab_fill\">False</property></packing></child><chi"
  "ld><object class=\"GtkScrolledWindow\" id=\"scrolledwindow1\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">True</pro"
  "perty><property name=\"border_width\">12</property><property name=\"hsc"
  "rollbar_policy\">automatic</property><property name=\"vscrollbar_policy"
  "\">automatic</property><property name=\"shadow_type\">etched-in</proper"
  "ty><child><object class=\"GtkTreeView\" id=\"icon_theme_treeview\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">True"
  "</property><property name=\"headers_visible\">False</property><property"
  " name=\"show_expanders\">False</property></object></child></object><pac"
  "king><property name=\"position\">1</property></packing></child><child t"
  "ype=\"tab\"><object class=\"GtkLabel\" id=\"label2\"><property name=\"v"
  "isible\">True</property><property name=\"label\" translatable=\"yes\">_"
  "Icons</property><property name=\"use_underline\">True</property></objec"
  "t><packing><property name=\"position\">1</property><property name=\"tab"
  "_fill\">False</property></packing></child><child><object class=\"GtkVBo"
  "x\" id=\"vbox3\"><property name=\"visible\">True</property><property na"
  "me=\"border_width\">12</property><property name=\"orientation\">vertica"
  "l</property><property name=\"spacing\">12</property><child><object clas"
  "s=\"GtkFrame\" id=\"frame3\"><property name=\"visible\">True</property>"
  "<property name=\"label_xalign\">0</property><property name=\"shadow_typ"
  "e\">none</property><child><object class=\"GtkAlignment\" id=\"alignment"
  "3\"><property name=\"visible\">True</property><property name=\"border_w"
  "idth\">6</property><property name=\"bottom_padding\">6</property><prope"
  "rty name=\"left_padding\">12</property><child><object class=\"GtkFontBu"
  "tton\" id=\"gtk_fontname_button\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">True</property><property name=\"recei"
  "ves_default\">True</property><property name=\"tooltip_text\" translatab"
  "le=\"yes\">This font will be used as the default font used when drawing"
  " user interface text</property><property name=\"title\" translatable=\""
  "yes\">Select a default font</property></object></child></object></child"
  "><child type=\"label\"><object class=\"GtkLabel\" id=\"label7\"><proper"
  "ty name=\"visible\">True</property><property name=\"label\" translatabl"
  "e=\"yes\">Default Fon_t</property><property name=\"use_underline\">True"
  "</property><property name=\"mnemonic_widget\">gtk_fontname_button</prop"
  "erty><attributes><attribute name=\"weight\" value=\"bold\"/></attribute"
  "s></object></child></object><packing><property name=\"expand\">False</p"
  "roperty><property name=\"position\">0</property></packing></child><chil"
  "d><object class=\"GtkFrame\" id=\"frame4\"><property name=\"visible\">T"
  "rue</property><property name=\"label_xalign\">0</property><property nam"
  "e=\"shadow_type\">none</property><child><object class=\"GtkAlignment\" "
  "id=\"alignment4\"><property name=\"visible\">True</property><property n"
  "ame=\"bottom_padding\">6</property><property name=\"left_padding\">12</"
  "property><child><object class=\"GtkTable\" id=\"table1\"><property name"
  "=\"visible\">True</property><property name=\"border_width\">6</property"
  "><property name=\"n_rows\">3</property><property name=\"n_columns\">2</"
  "property><property name=\"column_spacing\">12</property><property name="
  "\"row_spacing\">6</property><child><object class=\"GtkComboBox\" id=\"x"
  "ft_hinting_style_combo_box\"><property name=\"visible\">True</property>"
  "<property name=\"tooltip_text\" translatable=\"yes\">Many fonts contain"
  " information that provides extra hints as to how best draw the font; pi"
  "ck whichever looks best according to personal preference</property><pro"
  "perty name=\"model\">liststore1</property><child><object class=\"GtkCel"
  "lRendererText\" id=\"cellrenderertext1\"/><attributes><attribute name=\""
  "text\">0</attribute></attributes></child></object><packing><property na"
  "me=\"left_attach\">1</property><property name=\"right_attach\">2</prope"
  "rty><property name=\"top_attach\">1</property><property name=\"bottom_a"
  "ttach\">2</property></packing></child><child><object class=\"GtkComboBo"
  "x\" id=\"xft_rgba_combo_box\"><property name=\"visible\">True</property"
  "><property name=\"tooltip_text\" translatable=\"yes\">Font quality on a"
  " TFT or LCD screen can be greatly improved by choosing the correct sub-"
  "pixel order of the screen</property><property name=\"model\">xft_rgba_s"
  "tore</property><child><object class=\"GtkCellRendererText\" id=\"cellre"
  "nderertext3\"/><attributes><attribute name=\"text\">1</attribute></attr"
  "ibutes></child><child><object class=\"GtkCellRendererPixbuf\" id=\"cell"
  "rendererpixbuf1\"/><attributes><attribute name=\"pixbuf\">0</attribute>"
  "</attributes></child></object><packing><property name=\"left_attach\">1"
  "</property><property name=\"right_attach\">2</property><property name=\""
  "top_attach\">2</property><property name=\"bottom_attach\">3</property><"
  "/packing></child><child><object class=\"GtkLabel\" id=\"label11\"><prop"
  "erty name=\"visible\">True</property><property name=\"xalign\">1</prope"
  "rty><property name=\"label\" translatable=\"yes\">Sub-_pixel order:</pr"
  "operty><property name=\"use_underline\">True</property><property name=\""
  "mnemonic_widget\">xft_rgba_combo_box</property></object><packing><prope"
  "rty name=\"top_attach\">2</property><property name=\"bottom_attach\">3<"
  "/property><property name=\"x_options\">GTK_FILL</property></packing></c"
  "hild><child><object class=\"GtkLabel\" id=\"label10\"><property name=\""
  "visible\">True</property><property name=\"xalign\">0</property><propert"
  "y name=\"label\" translatable=\"yes\">_Hinting:</property><property nam"
  "e=\"use_underline\">True</property><property name=\"mnemonic_widget\">x"
  "ft_hinting_style_combo_box</property></object><packing><property name=\""
  "top_attach\">1</property><property name=\"bottom_attach\">2</property><"
  "property name=\"x_options\">GTK_FILL</property></packing></child><child"
  "><object class=\"GtkCheckButton\" id=\"xft_antialias_check_button\"><pr"
  "operty name=\"label\" translatable=\"yes\">Enable _anti-aliasing</prope"
  "rty><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">True</property><property name=\"receives_default\">False</property>"
  "<property name=\"tooltip_text\" translatable=\"yes\">Anti-aliasing, or "
  "font smoothing, can improve the look of text on the screen</property><p"
  "roperty name=\"use_underline\">True</property><property name=\"active\""
  ">True</property><property name=\"draw_indicator\">True</property></obje"
  "ct><packing><property name=\"right_attach\">2</property></packing></chi"
  "ld></object></child></object></child><child type=\"label\"><object clas"
  "s=\"GtkLabel\" id=\"label8\"><property name=\"visible\">True</property>"
  "<property name=\"label\" translatable=\"yes\">Rendering</property><attr"
  "ibutes><attribute name=\"weight\" value=\"bold\"/></attributes></object"
  "></child></object><packing><property name=\"expand\">False</property><p"
  "roperty name=\"position\">1</property></packing></child><child><object "
  "class=\"GtkFrame\" id=\"frame5\"><property name=\"visible\">True</prope"
  "rty><property name=\"label_xalign\">0</property><property name=\"shadow"
  "_type\">none</property><child><object class=\"GtkAlignment\" id=\"align"
  "ment5\"><property name=\"visible\">True</property><property name=\"bott"
  "om_padding\">6</property><property name=\"left_padding\">12</property><"
  "child><object class=\"GtkHBox\" id=\"hbox1\"><property name=\"visible\""
  ">True</property><property name=\"border_width\">6</property><property n"
  "ame=\"spacing\">12</property><child><object class=\"GtkCheckButton\" id"
  "=\"xft_custom_dpi_check_button\"><property name=\"label\" translatable="
  "\"yes\">Custom _DPI setting:</property><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">True</property><property name=\""
  "receives_default\">False</property><property name=\"tooltip_text\" tran"
  "slatable=\"yes\">Override the detected monitor resolution if fonts look"
  " too large or too small</property><property name=\"use_underline\">True"
  "</property><property name=\"draw_indicator\">True</property></object><p"
  "acking><property name=\"expand\">False</property><property name=\"posit"
  "ion\">0</property></packing></child><child><object class=\"GtkSpinButto"
  "n\" id=\"xft_custom_dpi_spin_button\"><property name=\"visible\">True</"
  "property><property name=\"sensitive\">False</property><property name=\""
  "can_focus\">True</property><property name=\"adjustment\">xft_custom_dpi"
  "</property><property name=\"snap_to_ticks\">True</property><property na"
  "me=\"numeric\">True</property><property name=\"update_policy\">if-valid"
  "</property></object><packing><property name=\"expand\">False</property>"
  "<property name=\"position\">1</property></packing></child></object></ch"
  "ild></object></child><child type=\"label\"><object class=\"GtkLabel\" i"
  "d=\"label9\"><property name=\"visible\">True</property><property name=\""
  "label\" translatable=\"yes\">DPI</property><attributes><attribute name="
  "\"weight\" value=\"bold\"/></attributes></object></child></object><pack"
  "ing><property name=\"expand\">False</property><property name=\"position"
  "\">2</property></packing></child></object><packing><property name=\"pos"
  "ition\">2</property></packing></child><child type=\"tab\"><object class"
  "=\"GtkLabel\" id=\"label3\"><property name=\"visible\">True</property><"
  "property name=\"label\" translatable=\"yes\">_Fonts</property><property"
  " name=\"use_underline\">True</property></object><packing><property name"
  "=\"position\">2</property><property name=\"tab_fill\">False</property><"
  "/packing></child><child><object class=\"GtkVBox\" id=\"vbox1\"><propert"
  "y name=\"visible\">True</property><property name=\"border_width\">12</p"
  "roperty><property name=\"orientation\">vertical</property><property nam"
  "e=\"spacing\">6</property><child><object class=\"GtkFrame\" id=\"frame2"
  "\"><property name=\"visible\">True</property><property name=\"label_xal"
  "ign\">0</property><property name=\"shadow_type\">none</property><child>"
  "<object class=\"GtkAlignment\" id=\"alignment2\"><property name=\"visib"
  "le\">True</property><property name=\"border_width\">6</property><proper"
  "ty name=\"bottom_padding\">6</property><property name=\"left_padding\">"
  "12</property><child><object class=\"GtkComboBox\" id=\"gtk_toolbar_styl"
  "e_combo_box\"><property name=\"visible\">True</property><property name="
  "\"tooltip_text\" translatable=\"yes\">Specify what should be displayed "
  "in toolbar items</property><property name=\"model\">liststore2</propert"
  "y><child><object class=\"GtkCellRendererText\" id=\"cellrenderertext2\""
  "/><attributes><attribute name=\"text\">0</attribute></attributes></chil"
  "d></object></child></object></child><child type=\"label\"><object class"
  "=\"GtkLabel\" id=\"label6\"><property name=\"visible\">True</property><"
  "property name=\"label\" translatable=\"yes\">_Toolbar Style</property><"
  "property name=\"use_underline\">True</property><property name=\"mnemoni"
  "c_widget\">gtk_toolbar_style_combo_box</property><attributes><attribute"
  " name=\"weight\" value=\"bold\"/></attributes></object></child></object"
  "><packing><property name=\"expand\">False</property><property name=\"po"
  "sition\">0</property></packing></child><child><object class=\"GtkFrame\""
  " id=\"frame1\"><property name=\"visible\">True</property><property name"
  "=\"label_xalign\">0</property><property name=\"shadow_type\">none</prop"
  "erty><child><object class=\"GtkAlignment\" id=\"alignment1\"><property "
  "name=\"visible\">True</property><property name=\"bottom_padding\">6</pr"
  "operty><property name=\"left_padding\">12</property><child><object clas"
  "s=\"GtkVBox\" id=\"vbox2\"><property name=\"visible\">True</property><p"
  "roperty name=\"border_width\">6</property><property name=\"orientation\""
  ">vertical</property><property name=\"spacing\">6</property><child><obje"
  "ct class=\"GtkCheckButton\" id=\"gtk_button_images_check_button\"><prop"
  "erty name=\"label\" translatable=\"yes\">Show images on _buttons</prope"
  "rty><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">True</property><property name=\"receives_default\">False</property>"
  "<property name=\"tooltip_text\" translatable=\"yes\">Specify whether ic"
  "ons should be displayed next to text in buttons</property><property nam"
  "e=\"use_underline\">True</property><property name=\"draw_indicator\">Tr"
  "ue</property></object><packing><property name=\"position\">0</property>"
  "</packing></child><child><object class=\"GtkCheckButton\" id=\"gtk_menu"
  "_images_check_button\"><property name=\"label\" translatable=\"yes\">Sh"
  "ow images in _menus</property><property name=\"visible\">True</property"
  "><property name=\"can_focus\">True</property><property name=\"receives_"
  "default\">False</property><property name=\"tooltip_text\" translatable="
  "\"yes\">Specify whether icons should be displayed next to items in menu"
  "s</property><property name=\"use_underline\">True</property><property n"
  "ame=\"draw_indicator\">True</property></object><packing><property name="
  "\"position\">1</property></packing></child><child><object class=\"GtkCh"
  "eckButton\" id=\"gtk_caneditaccels_check_button\"><property name=\"labe"
  "l\" translatable=\"yes\">Enable e_ditable accelerators</property><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">True</"
  "property><property name=\"receives_default\">False</property><property "
  "name=\"tooltip_text\" translatable=\"yes\">If selected, keyboard shortc"
  "uts for menu items can be changed by hovering the mouse over the menu i"
  "tem and pressing the new key combination for the shortcut</property><pr"
  "operty name=\"use_underline\">True</property><property name=\"draw_indi"
  "cator\">True</property></object><packing><property name=\"position\">2<"
  "/property></packing></child></object></child></object></child><child ty"
  "pe=\"label\"><object class=\"GtkLabel\" id=\"label5\"><property name=\""
  "visible\">True</property><property name=\"label\" translatable=\"yes\">"
  "Menus and Buttons</property><attributes><attribute name=\"weight\" valu"
  "e=\"bold\"/></attributes></object></child></object><packing><property n"
  "ame=\"expand\">False</property><property name=\"position\">1</property>"
  "</packing></child><child><object class=\"GtkFrame\" id=\"event_sounds_f"
  "rame\"><property name=\"label_xalign\">0</property><property name=\"sha"
  "dow_type\">none</property><child><object class=\"GtkAlignment\" id=\"al"
  "ignment6\"><property name=\"visible\">True</property><property name=\"b"
  "ottom_padding\">6</property><property name=\"left_padding\">12</propert"
  "y><child><object class=\"GtkVBox\" id=\"vbox4\"><property name=\"visibl"
  "e\">True</property><property name=\"border_width\">6</property><propert"
  "y name=\"orientation\">vertical</property><property name=\"spacing\">6<"
  "/property><child><object class=\"GtkCheckButton\" id=\"enable_event_sou"
  "nds_check_button\"><property name=\"label\" translatable=\"yes\">Enable"
  " _event sounds</property><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">True</property><property name=\"receives_defau"
  "lt\">False</property><property name=\"tooltip_text\" translatable=\"yes"
  "\">Enable or disable event sounds globally (requires \"Canberra\" suppo"
  "rt)</property><property name=\"use_underline\">True</property><property"
  " name=\"draw_indicator\">True</property></object><packing><property nam"
  "e=\"position\">0</property></packing></child><child><object class=\"Gtk"
  "CheckButton\" id=\"enable_input_feedback_sounds_button\"><property name"
  "=\"label\" translatable=\"yes\">Enable i_nput feedback sounds</property"
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">True</property><property name=\"receives_default\">False</property><pr"
  "operty name=\"tooltip_text\" translatable=\"yes\">Specify whether mouse"
  " clicks and other user input will cause event sounds to play</property>"
  "<property name=\"use_underline\">True</property><property name=\"draw_i"
  "ndicator\">True</property></object><packing><property name=\"position\""
  ">3</property></packing></child></object></child></object></child><child"
  " type=\"label\"><object class=\"GtkLabel\" id=\"label4\"><property name"
  "=\"visible\">True</property><property name=\"label\" translatable=\"yes"
  "\">Event sounds</property><attributes><attribute name=\"weight\" value="
  "\"bold\"/></attributes></object></child></object><packing><property nam"
  "e=\"position\">2</property></packing></child></object><packing><propert"
  "y name=\"position\">3</property></packing></child><child type=\"tab\"><"
  "object class=\"GtkLabel\" id=\"label12\"><property name=\"visible\">Tru"
  "e</property><property name=\"label\" translatable=\"yes\">_Settings</pr"
  "operty><property name=\"use_underline\">True</property></object><packin"
  "g><property name=\"position\">3</property><property name=\"tab_fill\">F"
  "alse</property></packing></child></object><packing><property name=\"pos"
  "ition\">1</property></packing></child><child internal-child=\"action_ar"
  "ea\"><object class=\"GtkHButtonBox\" id=\"dialog-action_area1\"><proper"
  "ty name=\"visible\">True</property><property name=\"layout_style\">end<"
  "/property><child><object class=\"GtkButton\" id=\"button1\"><property n"
  "ame=\"label\">gtk-close</property><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">True</property><property name=\"recei"
  "ves_default\">True</property><property name=\"use_stock\">True</propert"
  "y></object><packing><property name=\"expand\">False</property><property"
  " name=\"fill\">False</property><property name=\"position\">0</property>"
  "</packing></child><child><object class=\"GtkButton\" id=\"button2\"><pr"
  "operty name=\"label\">gtk-help</property><property name=\"use_action_ap"
  "pearance\">False</property><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">True</property><property name=\"receives_def"
  "ault\">True</property><property name=\"use_stock\">True</property></obj"
  "ect><packing><property name=\"expand\">False</property><property name=\""
  "fill\">False</property><property name=\"position\">0</property><propert"
  "y name=\"secondary\">True</property></packing></child></object><packing"
  "><property name=\"expand\">False</property><property name=\"pack_type\""
  ">end</property><property name=\"position\">0</property></packing></chil"
  "d></object></child><action-widgets><action-widget response=\"0\">button"
  "1</action-widget><action-widget response=\"-11\">button2</action-widget"
  "></action-widgets></object></interface>"
};

static const unsigned appearance_dialog_ui_length = 19961u;

