/* automatically generated from mouse-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (mouse_dialog_ui)
#endif
#ifdef __GNUC__
static const char mouse_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char mouse_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"2.20\"/><object class=\"GtkAdjustment\" id=\"dclick-dist"
  "ance\"><property name=\"upper\">20</property><property name=\"value\">4"
  "</property><property name=\"step_increment\">1</property><property name"
  "=\"page_increment\">5</property></object><object class=\"GtkAdjustment\""
  " id=\"dclick-time\"><property name=\"lower\">100</property><property na"
  "me=\"upper\">2000</property><property name=\"value\">250</property><pro"
  "perty name=\"step_increment\">1</property><property name=\"page_increme"
  "nt\">100</property></object><object class=\"GtkAdjustment\" id=\"device"
  "-acceleration\"><property name=\"lower\">0.10000000000000001</property>"
  "<property name=\"upper\">10</property><property name=\"value\">2</prope"
  "rty><property name=\"step_increment\">0.10000000000000001</property><pr"
  "operty name=\"page_increment\">1</property></object><object class=\"Gtk"
  "Adjustment\" id=\"device-threshold\"><property name=\"lower\">1</proper"
  "ty><property name=\"upper\">30</property><property name=\"value\">4</pr"
  "operty><property name=\"step_increment\">1</property><property name=\"p"
  "age_increment\">5</property></object><object class=\"GtkAdjustment\" id"
  "=\"dnd-threshold\"><property name=\"lower\">1</property><property name="
  "\"upper\">50</property><property name=\"value\">8</property><property n"
  "ame=\"step_increment\">1</property><property name=\"page_increment\">10"
  "</property></object><object class=\"GtkImage\" id=\"image5\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"stock\">gtk-revert-to-saved</property></object><"
  "object class=\"XfceTitledDialog\" id=\"mouse-dialog\"><property name=\""
  "can_focus\">False</property><property name=\"title\" translatable=\"yes"
  "\">Mouse and Touchpad</property><property name=\"window_position\">cent"
  "er-on-parent</property><property name=\"icon_name\">preferences-desktop"
  "-peripherals</property><property name=\"type_hint\">dialog</property><p"
  "roperty name=\"subtitle\" translatable=\"yes\">Configure pointer device"
  " behavior and appearance</property><child internal-child=\"vbox\"><obje"
  "ct class=\"GtkVBox\" id=\"dialog-vbox1\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"spacing\">2</property><child internal-child=\"action_area\"><object "
  "class=\"GtkHButtonBox\" id=\"dialog-action_area1\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"layout_style\">end</property><child><object class=\"GtkBut"
  "ton\" id=\"button1\"><property name=\"label\">gtk-close</property><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">True<"
  "/property><property name=\"receives_default\">True</property><property "
  "name=\"use_action_appearance\">False</property><property name=\"use_sto"
  "ck\">True</property></object><packing><property name=\"expand\">False</"
  "property><property name=\"fill\">False</property><property name=\"posit"
  "ion\">0</property></packing></child><child><object class=\"GtkButton\" "
  "id=\"button2\"><property name=\"label\">gtk-help</property><property na"
  "me=\"use_action_appearance\">False</property><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property><property n"
  "ame=\"receives_default\">True</property><property name=\"use_stock\">Tr"
  "ue</property></object><packing><property name=\"expand\">False</propert"
  "y><property name=\"fill\">False</property><property name=\"position\">0"
  "</property><property name=\"secondary\">True</property></packing></chil"
  "d></object><packing><property name=\"expand\">False</property><property"
  " name=\"fill\">True</property><property name=\"pack_type\">end</propert"
  "y><property name=\"position\">0</property></packing></child><child><obj"
  "ect class=\"GtkNotebook\" id=\"plug-child\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">True</property><property na"
  "me=\"border_width\">6</property><child><object class=\"GtkVBox\" id=\"v"
  "box1\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"border_width\">12</property><pr"
  "operty name=\"spacing\">6</property><child><object class=\"GtkHBox\" id"
  "=\"hbox1\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"spacing\">12</property><chi"
  "ld><object class=\"GtkLabel\" id=\"label7\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"label\" translatable=\"yes\">De_vice:</property><property name=\""
  "use_underline\">True</property><property name=\"mnemonic_widget\">devic"
  "e-combobox</property><property name=\"angle\">0.050000000000000003</pro"
  "perty></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">True</property><property name=\"position\">0</proper"
  "ty></packing></child><child><object class=\"GtkComboBox\" id=\"device-c"
  "ombobox\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">False</property></object><packing><property name=\"expand\">T"
  "rue</property><property name=\"fill\">True</property><property name=\"p"
  "osition\">1</property></packing></child></object><packing><property nam"
  "e=\"expand\">False</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">0</property></packing></child><child><object c"
  "lass=\"GtkCheckButton\" id=\"device-enabled\"><property name=\"label\" "
  "translatable=\"yes\">_Enable this device</property><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">True</property><prop"
  "erty name=\"receives_default\">False</property><property name=\"use_act"
  "ion_appearance\">False</property><property name=\"use_underline\">True<"
  "/property><property name=\"draw_indicator\">True</property></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">1</property></packing></chi"
  "ld><child><object class=\"GtkNotebook\" id=\"device-notebook\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">True</pr"
  "operty><child><object class=\"GtkVBox\" id=\"device-box\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"border_width\">6</property><property name=\"spacing"
  "\">6</property><child><object class=\"GtkFrame\" id=\"frame1\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"label_xalign\">0</property><property name=\"sh"
  "adow_type\">none</property><child><object class=\"GtkAlignment\" id=\"a"
  "lignment1\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"left_padding\">12</propert"
  "y><child><object class=\"GtkVBox\" id=\"vbox12\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"border_width\">6</property><property name=\"spacing\">6</pro"
  "perty><child><object class=\"GtkHBox\" id=\"hbox3\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"spacing\">12</property><child><object class=\"GtkRadioBut"
  "ton\" id=\"device-right-handed\"><property name=\"label\" translatable="
  "\"yes\">_Right-handed</property><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">True</property><property name=\"receive"
  "s_default\">False</property><property name=\"use_action_appearance\">Fa"
  "lse</property><property name=\"use_underline\">True</property><property"
  " name=\"active\">True</property><property name=\"draw_indicator\">True<"
  "/property></object><packing><property name=\"expand\">False</property><"
  "property name=\"fill\">True</property><property name=\"position\">0</pr"
  "operty></packing></child><child><object class=\"GtkRadioButton\" id=\"d"
  "evice-left-handed\"><property name=\"label\" translatable=\"yes\">_Left"
  "-handed</property><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">True</property><property name=\"receives_default\">Fa"
  "lse</property><property name=\"use_action_appearance\">False</property>"
  "<property name=\"use_underline\">True</property><property name=\"draw_i"
  "ndicator\">True</property><property name=\"group\">device-right-handed<"
  "/property></object><packing><property name=\"expand\">False</property><"
  "property name=\"fill\">True</property><property name=\"position\">1</pr"
  "operty></packing></child></object><packing><property name=\"expand\">Tr"
  "ue</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">0</property></packing></child><child><object class=\"GtkCheckB"
  "utton\" id=\"device-reverse-scrolling\"><property name=\"label\" transl"
  "atable=\"yes\">Reverse scroll d_irection</property><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">True</property><prop"
  "erty name=\"receives_default\">False</property><property name=\"tooltip"
  "_text\" translatable=\"yes\">When selected, the scroll wheel will work "
  "in the opposite direction</property><property name=\"use_action_appeara"
  "nce\">False</property><property name=\"use_underline\">True</property><"
  "property name=\"draw_indicator\">True</property></object><packing><prop"
  "erty name=\"expand\">True</property><property name=\"fill\">True</prope"
  "rty><property name=\"position\">1</property></packing></child></object>"
  "</child></object></child><child type=\"label\"><object class=\"GtkLabel"
  "\" id=\"label14\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"label\" translatable"
  "=\"yes\">Buttons</property><attributes><attribute name=\"weight\" value"
  "=\"bold\"/></attributes></object></child></object><packing><property na"
  "me=\"expand\">False</property><property name=\"fill\">True</property><p"
  "roperty name=\"position\">0</property></packing></child><child><object "
  "class=\"GtkFrame\" id=\"frame2\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"label"
  "_xalign\">0</property><property name=\"shadow_type\">none</property><ch"
  "ild><object class=\"GtkAlignment\" id=\"alignment2\"><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">False</property><p"
  "roperty name=\"left_padding\">12</property><child><object class=\"GtkTa"
  "ble\" id=\"table1\"><property name=\"visible\">True</property><property"
  " name=\"can_focus\">False</property><property name=\"border_width\">6</"
  "property><property name=\"n_rows\">3</property><property name=\"n_colum"
  "ns\">2</property><property name=\"column_spacing\">12</property><proper"
  "ty name=\"row_spacing\">6</property><child><object class=\"GtkLabel\" i"
  "d=\"device-acceleration-label\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"xalign"
  "\">0</property><property name=\"label\" translatable=\"yes\">_Accelerat"
  "ion:</property><property name=\"use_underline\">True</property><propert"
  "y name=\"mnemonic_widget\">device-acceleration-scale</property></object"
  "><packing><property name=\"x_options\">GTK_FILL</property><property nam"
  "e=\"y_options\">GTK_FILL</property></packing></child><child><object cla"
  "ss=\"GtkHScale\" id=\"device-acceleration-scale\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">True</property><prope"
  "rty name=\"tooltip_text\" translatable=\"yes\">The factor at which the "
  "pointer\'s speed will increase as the mouse is moved</property><propert"
  "y name=\"update_policy\">delayed</property><property name=\"adjustment\""
  ">device-acceleration</property><property name=\"round_digits\">1</prope"
  "rty><property name=\"value_pos\">right</property></object><packing><pro"
  "perty name=\"left_attach\">1</property><property name=\"right_attach\">"
  "2</property></packing></child><child><object class=\"GtkHScale\" id=\"d"
  "evice-threshold-scale\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">True</property><property name=\"tooltip_text\" "
  "translatable=\"yes\">The number of pixels the pointer must move in a sh"
  "ort time before it starts accelerating</property><property name=\"updat"
  "e_policy\">delayed</property><property name=\"adjustment\">device-thres"
  "hold</property><property name=\"round_digits\">0</property><property na"
  "me=\"digits\">0</property><property name=\"value_pos\">right</property>"
  "</object><packing><property name=\"left_attach\">1</property><property "
  "name=\"right_attach\">2</property><property name=\"top_attach\">1</prop"
  "erty><property name=\"bottom_attach\">2</property></packing></child><ch"
  "ild><object class=\"GtkLabel\" id=\"device-threshold-label\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"xalign\">0</property><property name=\"label\" tr"
  "anslatable=\"yes\">_Sensitivity:</property><property name=\"use_underli"
  "ne\">True</property><property name=\"mnemonic_widget\">device-threshold"
  "-scale</property></object><packing><property name=\"top_attach\">1</pro"
  "perty><property name=\"bottom_attach\">2</property><property name=\"x_o"
  "ptions\">GTK_FILL</property></packing></child><child><object class=\"Gt"
  "kAlignment\" id=\"alignment7\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"xalign\""
  ">0</property><property name=\"xscale\">0</property><property name=\"ysc"
  "ale\">0</property><child><object class=\"GtkButton\" id=\"device-reset-"
  "feedback\"><property name=\"label\" translatable=\"yes\">Reset to De_fa"
  "ults</property><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"receives_default\">True<"
  "/property><property name=\"tooltip_text\" translatable=\"yes\">Set the "
  "acceleration and sensitivity for the selected device to the default val"
  "ues</property><property name=\"use_action_appearance\">False</property>"
  "<property name=\"image\">image5</property><property name=\"use_underlin"
  "e\">True</property></object></child></object><packing><property name=\""
  "right_attach\">2</property><property name=\"top_attach\">2</property><p"
  "roperty name=\"bottom_attach\">3</property></packing></child></object><"
  "/child></object></child><child type=\"label\"><object class=\"GtkLabel\""
  " id=\"label15\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"label\" translatable=\""
  "yes\">Pointer Speed</property><attributes><attribute name=\"weight\" va"
  "lue=\"bold\"/></attributes></object></child></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">True</property"
  "><property name=\"position\">1</property></packing></child></object></c"
  "hild><child type=\"tab\"><object class=\"GtkLabel\" id=\"label4\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">False"
  "</property><property name=\"label\" translatable=\"yes\">B_uttons and F"
  "eedback</property><property name=\"use_underline\">True</property></obj"
  "ect><packing><property name=\"tab_fill\">False</property></packing></ch"
  "ild><child><object class=\"GtkVBox\" id=\"synaptics-tab\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"border_width\">6</property><property name=\"spacing"
  "\">6</property><child><object class=\"GtkFrame\" id=\"frame11\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"label_xalign\">0</property><property name=\"s"
  "hadow_type\">none</property><child><object class=\"GtkAlignment\" id=\""
  "alignment13\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"left_padding\">12</prope"
  "rty><child><object class=\"GtkVBox\" id=\"vbox11\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"border_width\">6</property><property name=\"spacing\">6</p"
  "roperty><child><object class=\"GtkCheckButton\" id=\"synaptics-disable-"
  "while-type\"><property name=\"label\" translatable=\"yes\">Disable to_u"
  "chpad while typing</property><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">True</property><property name=\"receives_d"
  "efault\">False</property><property name=\"tooltip_text\" translatable=\""
  "yes\">When selected, the touchpad will be disabled when the keyboard is"
  " being used</property><property name=\"use_action_appearance\">False</p"
  "roperty><property name=\"use_underline\">True</property><property name="
  "\"draw_indicator\">True</property></object><packing><property name=\"ex"
  "pand\">True</property><property name=\"fill\">True</property><property "
  "name=\"position\">0</property></packing></child><child><object class=\""
  "GtkCheckButton\" id=\"synaptics-tap-to-click\"><property name=\"label\""
  " translatable=\"yes\">T_ap touchpad to click</property><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"receives_default\">False</property><property name=\"use_"
  "action_appearance\">False</property><property name=\"use_underline\">Tr"
  "ue</property><property name=\"draw_indicator\">True</property></object>"
  "<packing><property name=\"expand\">True</property><property name=\"fill"
  "\">True</property><property name=\"position\">1</property></packing></c"
  "hild></object></child></object></child><child type=\"label\"><object cl"
  "ass=\"GtkLabel\" id=\"label16\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"label\""
  " translatable=\"yes\">General</property><property name=\"use_markup\">T"
  "rue</property><attributes><attribute name=\"weight\" value=\"bold\"/></"
  "attributes></object></child></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">True</property><property name="
  "\"position\">0</property></packing></child><child><object class=\"GtkFr"
  "ame\" id=\"frame10\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"label_xalign\">0<"
  "/property><property name=\"shadow_type\">none</property><child><object "
  "class=\"GtkAlignment\" id=\"alignment12\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"left_padding\">12</property><child><object class=\"GtkVBox\" id=\"v"
  "box10\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"border_width\">6</property><pr"
  "operty name=\"spacing\">6</property><child><object class=\"GtkHBox\" id"
  "=\"hbox4\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"spacing\">12</property><chi"
  "ld><object class=\"GtkRadioButton\" id=\"synaptics-scroll-no\"><propert"
  "y name=\"label\" translatable=\"yes\">Di_sabled</property><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">True</propert"
  "y><property name=\"receives_default\">False</property><property name=\""
  "use_action_appearance\">False</property><property name=\"use_underline\""
  ">True</property><property name=\"active\">True</property><property name"
  "=\"draw_indicator\">True</property></object><packing><property name=\"e"
  "xpand\">False</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">0</property></packing></child><child><object class="
  "\"GtkRadioButton\" id=\"synaptics-scroll-edge\"><property name=\"label\""
  " translatable=\"yes\">Edge scro_lling</property><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">True</property><propert"
  "y name=\"receives_default\">False</property><property name=\"use_action"
  "_appearance\">False</property><property name=\"use_underline\">True</pr"
  "operty><property name=\"draw_indicator\">True</property><property name="
  "\"group\">synaptics-scroll-no</property></object><packing><property nam"
  "e=\"expand\">False</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">1</property></packing></child><child><object c"
  "lass=\"GtkRadioButton\" id=\"synaptics-scroll-two\"><property name=\"la"
  "bel\" translatable=\"yes\">Two-_finger scrolling</property><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">True</proper"
  "ty><property name=\"receives_default\">False</property><property name=\""
  "use_action_appearance\">False</property><property name=\"use_underline\""
  ">True</property><property name=\"draw_indicator\">True</property><prope"
  "rty name=\"group\">synaptics-scroll-no</property></object><packing><pro"
  "perty name=\"expand\">True</property><property name=\"fill\">True</prop"
  "erty><property name=\"position\">2</property></packing></child></object"
  "><packing><property name=\"expand\">True</property><property name=\"fil"
  "l\">True</property><property name=\"position\">0</property></packing></"
  "child><child><object class=\"GtkCheckButton\" id=\"synaptics-scroll-hor"
  "iz\"><property name=\"label\" translatable=\"yes\">Enable hori_zontal s"
  "crolling</property><property name=\"visible\">True</property><property "
  "name=\"can_focus\">True</property><property name=\"receives_default\">F"
  "alse</property><property name=\"use_action_appearance\">False</property"
  "><property name=\"use_underline\">True</property><property name=\"draw_"
  "indicator\">True</property></object><packing><property name=\"expand\">"
  "True</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child></object></child></object></ch"
  "ild><child type=\"label\"><object class=\"GtkLabel\" id=\"label17\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property><property name=\"label\" translatable=\"yes\">Scrolling</p"
  "roperty><property name=\"use_markup\">True</property><attributes><attri"
  "bute name=\"weight\" value=\"bold\"/></attributes></object></child></ob"
  "ject><packing><property name=\"expand\">False</property><property name="
  "\"fill\">True</property><property name=\"position\">1</property></packi"
  "ng></child></object><packing><property name=\"position\">1</property></"
  "packing></child><child type=\"tab\"><object class=\"GtkLabel\" id=\"syn"
  "aptics-label\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property><property name=\"label\" translatable=\""
  "yes\">T_ouchpad</property><property name=\"use_underline\">True</proper"
  "ty></object><packing><property name=\"position\">1</property><property "
  "name=\"tab_fill\">False</property></packing></child><child><object clas"
  "s=\"GtkVBox\" id=\"wacom-tab\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"border_"
  "width\">6</property><property name=\"spacing\">6</property><child><obje"
  "ct class=\"GtkFrame\" id=\"frame12\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"l"
  "abel_xalign\">0</property><property name=\"shadow_type\">none</property"
  "><child><object class=\"GtkAlignment\" id=\"alignment14\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"left_padding\">12</property><child><object class=\""
  "GtkTable\" id=\"table2\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"border_width\""
  ">6</property><property name=\"n_rows\">2</property><property name=\"n_c"
  "olumns\">2</property><property name=\"column_spacing\">12</property><pr"
  "operty name=\"row_spacing\">6</property><child><object class=\"GtkLabel"
  "\" id=\"label9\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">False</property><property name=\"xalign\">0</property>"
  "<property name=\"label\" translatable=\"yes\">Tr_acking mode:</property"
  "><property name=\"use_underline\">True</property><property name=\"mnemo"
  "nic_widget\">wacom-mode</property></object><packing><property name=\"x_"
  "options\">GTK_FILL</property></packing></child><child><object class=\"G"
  "tkLabel\" id=\"label10\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"xalign\">0</p"
  "roperty><property name=\"label\" translatable=\"yes\">_Rotation:</prope"
  "rty><property name=\"use_underline\">True</property><property name=\"mn"
  "emonic_widget\">wacom-rotation</property></object><packing><property na"
  "me=\"top_attach\">1</property><property name=\"bottom_attach\">2</prope"
  "rty><property name=\"x_options\">GTK_FILL</property></packing></child><"
  "child><object class=\"GtkComboBox\" id=\"wacom-mode\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"model\">wacom-mode-store</property><child><object class"
  "=\"GtkCellRendererText\" id=\"cellrenderertext1\"/><attributes><attribu"
  "te name=\"text\">1</attribute></attributes></child></object><packing><p"
  "roperty name=\"left_attach\">1</property><property name=\"right_attach\""
  ">2</property></packing></child><child><object class=\"GtkComboBox\" id="
  "\"wacom-rotation\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">False</property><property name=\"model\">wacom-rotat"
  "ion-store</property><child><object class=\"GtkCellRendererText\" id=\"c"
  "ellrenderertext2\"/><attributes><attribute name=\"text\">1</attribute><"
  "/attributes></child></object><packing><property name=\"left_attach\">1<"
  "/property><property name=\"right_attach\">2</property><property name=\""
  "top_attach\">1</property><property name=\"bottom_attach\">2</property><"
  "/packing></child></object></child></object></child><child type=\"label\""
  "><object class=\"GtkLabel\" id=\"label18\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"label\" translatable=\"yes\">General</property><property name=\"us"
  "e_markup\">True</property><attributes><attribute name=\"weight\" value="
  "\"bold\"/></attributes></object></child></object><packing><property nam"
  "e=\"expand\">False</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">0</property></packing></child></object><packin"
  "g><property name=\"position\">2</property></packing></child><child type"
  "=\"tab\"><object class=\"GtkLabel\" id=\"wacom-label\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"label\" translatable=\"yes\">Table_t</property><propert"
  "y name=\"use_underline\">True</property></object><packing><property nam"
  "e=\"position\">2</property><property name=\"tab_fill\">False</property>"
  "</packing></child></object><packing><property name=\"expand\">True</pro"
  "perty><property name=\"fill\">True</property><property name=\"position\""
  ">2</property></packing></child></object></child><child type=\"tab\"><ob"
  "ject class=\"GtkLabel\" id=\"label1\"><property name=\"visible\">True</"
  "property><property name=\"can_focus\">False</property><property name=\""
  "label\" translatable=\"yes\">_Devices</property><property name=\"use_un"
  "derline\">True</property></object><packing><property name=\"tab_fill\">"
  "False</property></packing></child><child><object class=\"GtkVBox\" id=\""
  "vbox3\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"border_width\">12</property><p"
  "roperty name=\"spacing\">6</property><child><object class=\"GtkFrame\" "
  "id=\"frame3\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"label_xalign\">0</proper"
  "ty><property name=\"shadow_type\">none</property><child><object class=\""
  "GtkAlignment\" id=\"alignment3\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"left_"
  "padding\">12</property><child><object class=\"GtkVBox\" id=\"vbox4\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><property name=\"border_width\">6</property><property nam"
  "e=\"spacing\">6</property><child><object class=\"GtkLabel\" id=\"mouse-"
  "dnd-label\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"xalign\">0</property><prop"
  "erty name=\"label\" translatable=\"yes\">Th_reshold:</property><propert"
  "y name=\"use_underline\">True</property><property name=\"mnemonic_widge"
  "t\">dnd-threshold-scale</property></object><packing><property name=\"ex"
  "pand\">True</property><property name=\"fill\">True</property><property "
  "name=\"position\">0</property></packing></child><child><object class=\""
  "GtkHScale\" id=\"dnd-threshold-scale\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">True</property><property name=\""
  "tooltip_text\" translatable=\"yes\">The number of pixels the pointer mu"
  "st move before a drag operation will start</property><property name=\"u"
  "pdate_policy\">delayed</property><property name=\"adjustment\">dnd-thre"
  "shold</property><property name=\"digits\">0</property><property name=\""
  "value_pos\">right</property></object><packing><property name=\"expand\""
  ">True</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child></object></child></object></ch"
  "ild><child type=\"label\"><object class=\"GtkLabel\" id=\"label6\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"label\" translatable=\"yes\">Drag and Drop"
  "</property><attributes><attribute name=\"weight\" value=\"bold\"/></att"
  "ributes></object></child></object><packing><property name=\"expand\">Fa"
  "lse</property><property name=\"fill\">True</property><property name=\"p"
  "osition\">0</property></packing></child><child><object class=\"GtkFrame"
  "\" id=\"frame4\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">False</property><property name=\"label_xalign\">0</pro"
  "perty><property name=\"shadow_type\">none</property><child><object clas"
  "s=\"GtkAlignment\" id=\"alignment4\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"l"
  "eft_padding\">12</property><child><object class=\"GtkVBox\" id=\"vbox5\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"border_width\">6</property><property "
  "name=\"spacing\">6</property><child><object class=\"GtkLabel\" id=\"dcl"
  "ick-time-label\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">False</property><property name=\"xalign\">0</property>"
  "<property name=\"label\" translatable=\"yes\">Ti_me:</property><propert"
  "y name=\"use_underline\">True</property><property name=\"mnemonic_widge"
  "t\">dclick-time-scale</property></object><packing><property name=\"expa"
  "nd\">True</property><property name=\"fill\">True</property><property na"
  "me=\"position\">0</property></packing></child><child><object class=\"Gt"
  "kHScale\" id=\"dclick-time-scale\"><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">True</property><property name=\"tool"
  "tip_text\" translatable=\"yes\">Two mouse clicks in less than this leng"
  "th of time (in milliseconds) will be considered a double click</propert"
  "y><property name=\"update_policy\">delayed</property><property name=\"a"
  "djustment\">dclick-time</property><property name=\"digits\">0</property"
  "><property name=\"value_pos\">right</property></object><packing><proper"
  "ty name=\"expand\">True</property><property name=\"fill\">True</propert"
  "y><property name=\"position\">1</property></packing></child><child><obj"
  "ect class=\"GtkLabel\" id=\"dclick-distance-label\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"xalign\">0</property><property name=\"label\" translatabl"
  "e=\"yes\">D_istance:</property><property name=\"use_underline\">True</p"
  "roperty><property name=\"mnemonic_widget\">dclick-distance-scale</prope"
  "rty></object><packing><property name=\"expand\">True</property><propert"
  "y name=\"fill\">True</property><property name=\"position\">2</property>"
  "</packing></child><child><object class=\"GtkHScale\" id=\"dclick-distan"
  "ce-scale\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">True</property><property name=\"tooltip_text\" translatable="
  "\"yes\">The mouse pointer cannot move farther than this distance betwee"
  "n two clicks for them to be considered a double click</property><proper"
  "ty name=\"update_policy\">delayed</property><property name=\"adjustment"
  "\">dclick-distance</property><property name=\"digits\">0</property><pro"
  "perty name=\"value_pos\">right</property></object><packing><property na"
  "me=\"expand\">True</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">3</property></packing></child></object></child"
  "></object></child><child type=\"label\"><object class=\"GtkLabel\" id=\""
  "label8\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"label\" translatable=\"yes\">"
  "Double Click</property><attributes><attribute name=\"weight\" value=\"b"
  "old\"/></attributes></object></child></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">1</property></packing></child></object><packing><p"
  "roperty name=\"position\">1</property></packing></child><child type=\"t"
  "ab\"><object class=\"GtkLabel\" id=\"label2\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"label\" translatable=\"yes\">_Behavior</property><property name="
  "\"use_underline\">True</property></object><packing><property name=\"pos"
  "ition\">1</property><property name=\"tab_fill\">False</property></packi"
  "ng></child><child><object class=\"GtkHBox\" id=\"themes-hbox\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"border_width\">12</property><property name=\"s"
  "pacing\">12</property><child><object class=\"GtkScrolledWindow\" id=\"s"
  "crolledwindow2\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">True</property><property name=\"hscrollbar_policy\">au"
  "tomatic</property><property name=\"vscrollbar_policy\">automatic</prope"
  "rty><property name=\"shadow_type\">etched-in</property><child><object c"
  "lass=\"GtkTreeView\" id=\"theme-treeview\"><property name=\"width_reque"
  "st\">200</property><property name=\"visible\">True</property><property "
  "name=\"can_focus\">True</property><property name=\"headers_visible\">Fa"
  "lse</property></object></child></object><packing><property name=\"expan"
  "d\">True</property><property name=\"fill\">True</property><property nam"
  "e=\"position\">0</property></packing></child><child><object class=\"Gtk"
  "VBox\" id=\"vbox9\"><property name=\"visible\">True</property><property"
  " name=\"can_focus\">False</property><property name=\"spacing\">6</prope"
  "rty><child><object class=\"GtkFrame\" id=\"frame5\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"label_xalign\">0</property><property name=\"shadow_type\""
  ">none</property><child><object class=\"GtkAlignment\" id=\"alignment5\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"left_padding\">12</property><child><o"
  "bject class=\"GtkHBox\" id=\"hbox7\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"b"
  "order_width\">6</property><property name=\"spacing\">12</property><chil"
  "d><object class=\"GtkLabel\" id=\"label21\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"label\" translatable=\"yes\">Cursor _size:</property><property na"
  "me=\"use_underline\">True</property><property name=\"mnemonic_widget\">"
  "spin1</property></object><packing><property name=\"expand\">False</prop"
  "erty><property name=\"fill\">True</property><property name=\"position\""
  ">0</property></packing></child><child><object class=\"GtkSpinButton\" i"
  "d=\"spin1\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"primary_icon_activatable\">"
  "False</property><property name=\"secondary_icon_activatable\">False</pr"
  "operty><property name=\"primary_icon_sensitive\">True</property><proper"
  "ty name=\"secondary_icon_sensitive\">True</property><property name=\"ad"
  "justment\">theme-cursor-size</property><property name=\"snap_to_ticks\""
  ">True</property><property name=\"numeric\">True</property></object><pac"
  "king><property name=\"expand\">False</property><property name=\"fill\">"
  "True</property><property name=\"position\">1</property></packing></chil"
  "d></object></child></object></child><child type=\"label\"><object class"
  "=\"GtkLabel\" id=\"label20\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><property name=\"label\" t"
  "ranslatable=\"yes\">Size</property><attributes><attribute name=\"weight"
  "\" value=\"bold\"/></attributes></object></child></object><packing><pro"
  "perty name=\"expand\">False</property><property name=\"fill\">True</pro"
  "perty><property name=\"position\">0</property></packing></child><child>"
  "<object class=\"GtkFrame\" id=\"frame6\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"label_xalign\">0</property><property name=\"shadow_type\">none</prop"
  "erty><child><object class=\"GtkAlignment\" id=\"alignment6\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"border_width\">6</property><property name=\"xali"
  "gn\">0</property><property name=\"yalign\">0</property><property name=\""
  "xscale\">0</property><property name=\"yscale\">0</property><property na"
  "me=\"top_padding\">6</property><property name=\"bottom_padding\">6</pro"
  "perty><property name=\"left_padding\">18</property><property name=\"rig"
  "ht_padding\">6</property><child><object class=\"GtkImage\" id=\"theme-p"
  "review\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"stock\">gtk-missing-image</pr"
  "operty></object></child></object></child><child type=\"label\"><object "
  "class=\"GtkLabel\" id=\"label22\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">False</property><property name=\"labe"
  "l\" translatable=\"yes\">Preview</property><attributes><attribute name="
  "\"weight\" value=\"bold\"/></attributes></object></child></object><pack"
  "ing><property name=\"expand\">False</property><property name=\"fill\">T"
  "rue</property><property name=\"position\">1</property></packing></child"
  "></object><packing><property name=\"expand\">False</property><property "
  "name=\"fill\">True</property><property name=\"position\">1</property></"
  "packing></child></object><packing><property name=\"position\">2</proper"
  "ty></packing></child><child type=\"tab\"><object class=\"GtkLabel\" id="
  "\"label3\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"label\" translatable=\"yes\""
  ">T_heme</property><property name=\"use_underline\">True</property></obj"
  "ect><packing><property name=\"position\">2</property><property name=\"t"
  "ab_fill\">False</property></packing></child></object><packing><property"
  " name=\"expand\">True</property><property name=\"fill\">True</property>"
  "<property name=\"position\">1</property></packing></child></object></ch"
  "ild><action-widgets><action-widget response=\"0\">button1</action-widge"
  "t><action-widget response=\"-11\">button2</action-widget></action-widge"
  "ts></object><object class=\"GtkAdjustment\" id=\"theme-cursor-size\"><p"
  "roperty name=\"lower\">16</property><property name=\"upper\">48</proper"
  "ty><property name=\"value\">24</property><property name=\"step_incremen"
  "t\">1</property><property name=\"page_increment\">11</property></object"
  "><object class=\"GtkListStore\" id=\"wacom-mode-store\"><columns><colum"
  "n type=\"gchararray\"/><column type=\"gchararray\"/></columns><data><ro"
  "w><col id=\"0\">ABSOLUTE</col><col id=\"1\" translatable=\"yes\">Pen (a"
  "bsolute)</col></row><row><col id=\"0\">RELATIVE</col><col id=\"1\" tran"
  "slatable=\"yes\">Mouse (relative)</col></row></data></object><object cl"
  "ass=\"GtkListStore\" id=\"wacom-rotation-store\"><columns><column type="
  "\"gint\"/><column type=\"gchararray\"/></columns><data><row><col id=\"0"
  "\">0</col><col id=\"1\" translatable=\"yes\">None (right-handed)</col><"
  "/row><row><col id=\"0\">3</col><col id=\"1\" translatable=\"yes\">Half "
  "(left-handed)</col></row><row><col id=\"0\">1</col><col id=\"1\" transl"
  "atable=\"yes\">Clockwise</col></row><row><col id=\"0\">2</col><col id=\""
  "1\" translatable=\"yes\">Counterclockwise</col></row></data></object></"
  "interface>"
};

static const unsigned mouse_dialog_ui_length = 37918u;

