/* automatically generated from minimal-display-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (minimal_display_dialog_ui)
#endif
#ifdef __GNUC__
static const char minimal_display_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char minimal_display_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\"?><interface><object class=\"GtkDialog\" id=\"dial"
  "og1\"><property name=\"border_width\">5</property><property name=\"titl"
  "e\" translatable=\"yes\">Display settings</property><property name=\"re"
  "sizable\">False</property><property name=\"window_position\">center</pr"
  "operty><property name=\"icon_name\">video-display</property><property n"
  "ame=\"type_hint\">normal</property><property name=\"has_separator\">Fal"
  "se</property><child internal-child=\"vbox\"><object class=\"GtkVBox\" i"
  "d=\"dialog-vbox1\"><property name=\"visible\">True</property><property "
  "name=\"orientation\">vertical</property><property name=\"spacing\">2</p"
  "roperty><child><object class=\"GtkVBox\" id=\"vbox1\"><property name=\""
  "visible\">True</property><property name=\"orientation\">vertical</prope"
  "rty><child><object class=\"GtkLabel\" id=\"label1\"><property name=\"vi"
  "sible\">True</property><property name=\"label\" translatable=\"yes\">Se"
  "veral displays are available. Use:\n</property></object><packing><prope"
  "rty name=\"position\">0</property></packing></child><child><object clas"
  "s=\"GtkHBox\" id=\"hbox1\"><property name=\"visible\">True</property><c"
  "hild><object class=\"GtkImage\" id=\"image1\"><property name=\"visible\""
  ">True</property><property name=\"xpad\">20</property><property name=\"p"
  "ixel_size\">64</property><property name=\"icon_name\">video-display</pr"
  "operty></object><packing><property name=\"expand\">False</property><pro"
  "perty name=\"fill\">False</property><property name=\"position\">0</prop"
  "erty></packing></child><child><object class=\"GtkVBox\" id=\"vbox3\"><p"
  "roperty name=\"visible\">True</property><property name=\"orientation\">"
  "vertical</property><property name=\"spacing\">4</property><child><objec"
  "t class=\"GtkRadioButton\" id=\"radiobutton1\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">True</property><property"
  " name=\"receives_default\">True</property><property name=\"active\">Tru"
  "e</property><property name=\"draw_indicator\">True</property></object><"
  "packing><property name=\"position\">0</property></packing></child><chil"
  "d><object class=\"GtkRadioButton\" id=\"radiobutton2\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"receives_default\">True</property><property name=\"activ"
  "e\">True</property><property name=\"draw_indicator\">True</property><pr"
  "operty name=\"group\">radiobutton1</property></object><packing><propert"
  "y name=\"position\">1</property></packing></child><child><object class="
  "\"GtkRadioButton\" id=\"radiobutton3\"><property name=\"label\" transla"
  "table=\"yes\">Both displays cloned</property><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property><property n"
  "ame=\"receives_default\">True</property><property name=\"tooltip_text\""
  " translatable=\"yes\">Use both displays to show the same contents</prop"
  "erty><property name=\"active\">True</property><property name=\"draw_ind"
  "icator\">True</property><property name=\"group\">radiobutton1</property"
  "></object><packing><property name=\"position\">2</property></packing></"
  "child></object><packing><property name=\"position\">1</property></packi"
  "ng></child></object><packing><property name=\"position\">1</property></"
  "packing></child></object><packing><property name=\"padding\">4</propert"
  "y><property name=\"position\">1</property></packing></child><child inte"
  "rnal-child=\"action_area\"><object class=\"GtkHButtonBox\" id=\"dialog-"
  "action_area1\"><property name=\"visible\">True</property><property name"
  "=\"layout_style\">end</property><child><object class=\"GtkButton\" id=\""
  "button2\"><property name=\"label\">gtk-cancel</property><property name="
  "\"visible\">True</property><property name=\"can_focus\">True</property>"
  "<property name=\"receives_default\">True</property><property name=\"use"
  "_stock\">True</property></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">False</property><property name=\"p"
  "osition\">0</property></packing></child><child><object class=\"GtkButto"
  "n\" id=\"button1\"><property name=\"label\">gtk-ok</property><property "
  "name=\"visible\">True</property><property name=\"can_focus\">True</prop"
  "erty><property name=\"can_default\">True</property><property name=\"has"
  "_default\">True</property><property name=\"receives_default\">True</pro"
  "perty><property name=\"use_stock\">True</property></object><packing><pr"
  "operty name=\"expand\">False</property><property name=\"fill\">False</p"
  "roperty><property name=\"position\">1</property></packing></child></obj"
  "ect><packing><property name=\"expand\">False</property><property name=\""
  "pack_type\">end</property><property name=\"position\">0</property></pac"
  "king></child></object></child><action-widgets><action-widget response=\""
  "0\">button2</action-widget><action-widget response=\"1\">button1</actio"
  "n-widget></action-widgets></object></interface>"
};

static const unsigned minimal_display_dialog_ui_length = 4588u;

