
#ifndef ___xfce_settings_marshal_MARSHAL_H__
#define ___xfce_settings_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:STRING,BOXED (xfce-settings-marshal.list:1) */
G_GNUC_INTERNAL void _xfce_settings_marshal_VOID__STRING_BOXED (GClosure     *closure,
                                                                GValue       *return_value,
                                                                guint         n_param_values,
                                                                const GValue *param_values,
                                                                gpointer      invocation_hint,
                                                                gpointer      marshal_data);

G_END_DECLS

#endif /* ___xfce_settings_marshal_MARSHAL_H__ */

