/* automatically generated from confirmation-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (confirmation_dialog_ui)
#endif
#ifdef __GNUC__
static const char confirmation_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char confirmation_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\"?><interface><object class=\"GtkDialog\" id=\"dial"
  "og1\"><property name=\"border_width\">5</property><property name=\"titl"
  "e\" translatable=\"yes\">Confirmation</property><property name=\"resiza"
  "ble\">False</property><property name=\"window_position\">center</proper"
  "ty><property name=\"icon_name\">dialog-question</property><property nam"
  "e=\"type_hint\">normal</property><property name=\"has_separator\">False"
  "</property><child internal-child=\"vbox\"><object class=\"GtkVBox\" id="
  "\"dialog-vbox1\"><property name=\"visible\">True</property><property na"
  "me=\"orientation\">vertical</property><property name=\"spacing\">2</pro"
  "perty><child><object class=\"GtkHBox\" id=\"hbox1\"><property name=\"vi"
  "sible\">True</property><child><object class=\"GtkImage\" id=\"image1\">"
  "<property name=\"visible\">True</property><property name=\"xalign\">0.2"
  "0000000298023224</property><property name=\"xpad\">10</property><proper"
  "ty name=\"stock\">gtk-dialog-question</property><property name=\"icon-s"
  "ize\">6</property></object><packing><property name=\"expand\">False</pr"
  "operty><property name=\"fill\">False</property><property name=\"positio"
  "n\">0</property></packing></child><child><object class=\"GtkVBox\" id=\""
  "vbox1\"><property name=\"visible\">True</property><property name=\"orie"
  "ntation\">vertical</property><child><object class=\"GtkLabel\" id=\"lab"
  "el1\"><property name=\"visible\">True</property><property name=\"xalign"
  "\">0</property><property name=\"yalign\">0</property><property name=\"y"
  "pad\">10</property><property name=\"label\" translatable=\"yes\">&lt;bi"
  "g&gt;&lt;b&gt;Would you like to keep this configuration?&lt;/b&gt;&lt;/"
  "big&gt;</property><property name=\"use_markup\">True</property></object"
  "><packing><property name=\"expand\">False</property><property name=\"fi"
  "ll\">False</property><property name=\"position\">0</property></packing>"
  "</child><child><object class=\"GtkLabel\" id=\"label2\"><property name="
  "\"visible\">True</property><property name=\"xalign\">0</property><prope"
  "rty name=\"yalign\">0</property><property name=\"ypad\">10</property><p"
  "roperty name=\"label\" translatable=\"yes\">The previous configuration "
  "will be restored in 10 seconds if you do not reply to this question.</p"
  "roperty><property name=\"wrap\">True</property></object><packing><prope"
  "rty name=\"expand\">False</property><property name=\"fill\">False</prop"
  "erty><property name=\"position\">1</property></packing></child></object"
  "><packing><property name=\"position\">1</property></packing></child></o"
  "bject><packing><property name=\"position\">1</property></packing></chil"
  "d><child internal-child=\"action_area\"><object class=\"GtkHButtonBox\""
  " id=\"dialog-action_area1\"><property name=\"visible\">True</property><"
  "property name=\"layout_style\">end</property><child><object class=\"Gtk"
  "Button\" id=\"button2\"><property name=\"label\" translatable=\"yes\">K"
  "eep this configuration</property><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">True</property><property name=\"can_de"
  "fault\">True</property><property name=\"has_default\">True</property><p"
  "roperty name=\"receives_default\">True</property></object><packing><pro"
  "perty name=\"expand\">False</property><property name=\"fill\">False</pr"
  "operty><property name=\"position\">0</property></packing></child><child"
  "><object class=\"GtkButton\" id=\"button1\"><property name=\"label\" tr"
  "anslatable=\"yes\">Restore the previous configuration</property><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">True</p"
  "roperty><property name=\"receives_default\">True</property></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">False</property><property name=\"position\">1</property></packing></ch"
  "ild></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"pack_type\">end</property><property name=\"position\">0</prop"
  "erty></packing></child></object></child><action-widgets><action-widget "
  "response=\"2\">button2</action-widget><action-widget response=\"1\">but"
  "ton1</action-widget></action-widgets></object></interface>"
};

static const unsigned confirmation_dialog_ui_length = 3851u;

