/* automatically generated from display-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (display_dialog_ui)
#endif
#ifdef __GNUC__
static const char display_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char display_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\"?><interface><requires lib=\"gtk+\" version=\"2.14"
  "\"/><object class=\"XfceTitledDialog\" id=\"display-dialog\"><property "
  "name=\"title\" translatable=\"yes\">Display</property><property name=\""
  "window_position\">center-on-parent</property><property name=\"default_w"
  "idth\">400</property><property name=\"default_height\">350</property><p"
  "roperty name=\"icon_name\">video-display</property><property name=\"typ"
  "e_hint\">dialog</property><property name=\"has_separator\">False</prope"
  "rty><property name=\"subtitle\" translatable=\"yes\">Configure screen s"
  "ettings and layout</property><child internal-child=\"vbox\"><object cla"
  "ss=\"GtkVBox\" id=\"dialog-vbox1\"><property name=\"visible\">True</pro"
  "perty><property name=\"orientation\">vertical</property><property name="
  "\"spacing\">2</property><child><object class=\"GtkHBox\" id=\"plug-chil"
  "d\"><property name=\"visible\">True</property><property name=\"border_w"
  "idth\">12</property><property name=\"spacing\">12</property><child><obj"
  "ect class=\"GtkScrolledWindow\" id=\"scrolledwindow1\"><property name=\""
  "width_request\">200</property><property name=\"visible\">True</property"
  "><property name=\"can_focus\">True</property><property name=\"hscrollba"
  "r_policy\">automatic</property><property name=\"vscrollbar_policy\">aut"
  "omatic</property><property name=\"shadow_type\">etched-in</property><ch"
  "ild><object class=\"GtkTreeView\" id=\"randr-outputs\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"headers_visible\">False</property><property name=\"enabl"
  "e_search\">False</property><property name=\"show_expanders\">False</pro"
  "perty></object></child></object></child><child><object class=\"GtkVBox\""
  " id=\"vbox1\"><property name=\"visible\">True</property><property name="
  "\"border_width\">12</property><property name=\"spacing\">12</property><"
  "child><object class=\"GtkCheckButton\" id=\"output-on\"><property name="
  "\"label\" translatable=\"yes\">_Use this output</property><property nam"
  "e=\"use_underline\">True</property></object><packing><property name=\"p"
  "osition\">0</property></packing></child><child><object class=\"GtkTable"
  "\" id=\"table1\"><property name=\"visible\">True</property><property na"
  "me=\"n_rows\">4</property><property name=\"n_columns\">2</property><pro"
  "perty name=\"column_spacing\">12</property><property name=\"row_spacing"
  "\">6</property><child><object class=\"GtkLabel\" id=\"label-reflection\""
  "><property name=\"xalign\">0</property><property name=\"label\" transla"
  "table=\"yes\">Ref_lection:</property><property name=\"use_underline\">T"
  "rue</property><property name=\"mnemonic_widget\">randr-reflection</prop"
  "erty></object><packing><property name=\"top_attach\">3</property><prope"
  "rty name=\"bottom_attach\">4</property><property name=\"x_options\">GTK"
  "_FILL</property><property name=\"y_options\">GTK_FILL</property></packi"
  "ng></child><child><object class=\"GtkLabel\" id=\"label5\"><property na"
  "me=\"visible\">True</property><property name=\"xalign\">0</property><pr"
  "operty name=\"label\" translatable=\"yes\">Ro_tation:</property><proper"
  "ty name=\"use_underline\">True</property><property name=\"mnemonic_widg"
  "et\">randr-rotation</property></object><packing><property name=\"top_at"
  "tach\">2</property><property name=\"bottom_attach\">3</property><proper"
  "ty name=\"x_options\">GTK_FILL</property><property name=\"y_options\">G"
  "TK_FILL</property></packing></child><child><object class=\"GtkLabel\" i"
  "d=\"label4\"><property name=\"visible\">True</property><property name=\""
  "xalign\">0</property><property name=\"label\" translatable=\"yes\">Refr"
  "esh _rate:</property><property name=\"use_underline\">True</property><p"
  "roperty name=\"mnemonic_widget\">randr-refresh-rate</property></object>"
  "<packing><property name=\"top_attach\">1</property><property name=\"bot"
  "tom_attach\">2</property><property name=\"x_options\">GTK_FILL</propert"
  "y><property name=\"y_options\">GTK_FILL</property></packing></child><ch"
  "ild><object class=\"GtkLabel\" id=\"label3\"><property name=\"visible\""
  ">True</property><property name=\"xalign\">0</property><property name=\""
  "label\" translatable=\"yes\">R_esolution:</property><property name=\"us"
  "e_underline\">True</property><property name=\"mnemonic_widget\">randr-r"
  "esolution</property></object><packing><property name=\"x_options\">GTK_"
  "FILL</property><property name=\"y_options\">GTK_FILL</property></packin"
  "g></child><child><object class=\"GtkComboBox\" id=\"randr-reflection\"/"
  "><packing><property name=\"left_attach\">1</property><property name=\"r"
  "ight_attach\">2</property><property name=\"top_attach\">3</property><pr"
  "operty name=\"bottom_attach\">4</property><property name=\"y_options\">"
  "GTK_FILL</property></packing></child><child><object class=\"GtkComboBox"
  "\" id=\"randr-rotation\"><property name=\"visible\">True</property></ob"
  "ject><packing><property name=\"left_attach\">1</property><property name"
  "=\"right_attach\">2</property><property name=\"top_attach\">2</property"
  "><property name=\"bottom_attach\">3</property><property name=\"y_option"
  "s\">GTK_FILL</property></packing></child><child><object class=\"GtkComb"
  "oBox\" id=\"randr-refresh-rate\"><property name=\"visible\">True</prope"
  "rty></object><packing><property name=\"left_attach\">1</property><prope"
  "rty name=\"right_attach\">2</property><property name=\"top_attach\">1</"
  "property><property name=\"bottom_attach\">2</property><property name=\""
  "y_options\">GTK_FILL</property></packing></child><child><object class=\""
  "GtkComboBox\" id=\"randr-resolution\"><property name=\"visible\">True</"
  "property></object><packing><property name=\"left_attach\">1</property><"
  "property name=\"right_attach\">2</property><property name=\"y_options\""
  ">GTK_FILL</property></packing></child></object></child></object><packin"
  "g><property name=\"position\">1</property></packing></child></object><p"
  "acking><property name=\"position\">1</property></packing></child><child"
  " internal-child=\"action_area\"><object class=\"GtkHButtonBox\" id=\"di"
  "alog-action_area1\"><property name=\"visible\">True</property><property"
  " name=\"layout_style\">end</property><child><object class=\"GtkButton\""
  " id=\"button-close\"><property name=\"label\">gtk-close</property><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">True<"
  "/property><property name=\"receives_default\">True</property><property "
  "name=\"use_stock\">True</property></object><packing><property name=\"ex"
  "pand\">False</property><property name=\"fill\">False</property><propert"
  "y name=\"position\">1</property></packing></child><child><object class="
  "\"GtkButton\" id=\"button-help\"><property name=\"label\">gtk-help</pro"
  "perty><property name=\"use_action_appearance\">False</property><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">True</pr"
  "operty><property name=\"receives_default\">True</property><property nam"
  "e=\"use_stock\">True</property></object><packing><property name=\"expan"
  "d\">False</property><property name=\"fill\">False</property><property n"
  "ame=\"position\">0</property><property name=\"secondary\">True</propert"
  "y></packing></child></object><packing><property name=\"expand\">False</"
  "property><property name=\"pack_type\">end</property><property name=\"po"
  "sition\">0</property></packing></child></object></child><action-widgets"
  "><action-widget response=\"0\">button-close</action-widget><action-widg"
  "et response=\"-11\">button-help</action-widget></action-widgets></objec"
  "t></interface>"
};

static const unsigned display_dialog_ui_length = 6999u;

